@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2020 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -86,10 +86,14 @@ public final class GoogleOAuthServiceMetaData extends AbstractOAuthServiceMetaDa
 
     private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(GoogleOAuthServiceMetaData.class);
 
-    private static final String[] PROPERTIES = new String[] {"com.openexchange.oauth.google.apiKey", "com.openexchange.oauth.google.apiSecret"};
+    private static final String[] PROPERTIES = new String[]
+        {"com.openexchange.oauth.google.apiKey",
+        "com.openexchange.oauth.google.apiSecret",
+        "com.openexchange.oauth.google.redirectUrl",
+        "com.openexchange.oauth.google.productName"};
 
     private final ServiceLookup services;
-    private final String redirectUrl;
+    private String redirectUrl;
 
     /**
      * Initializes a new {@link GoogleOAuthServiceMetaData}.
@@ -167,6 +171,13 @@ public final class GoogleOAuthServiceMetaData extends AbstractOAuthServiceMetaDa
             throw new IllegalStateException("Missing following property in configuration: com.openexchange.oauth.google.apiSecret");
         }
         this.apiSecret = apiSecret;
+
+        String redirectUrl = configService.getProperty("com.openexchange.oauth.google.redirectUrl");
+        if (Strings.isEmpty(redirectUrl)) {
+            throw new IllegalStateException("Missing following property in configuration: com.openexchange.oauth.google.redirectUrl");
+        }
+        redirectUrl = redirectUrl.replaceAll(":", "%3A").replaceAll("/", "%2F");
+        this.redirectUrl = redirectUrl;
     }
 
     @Override
