@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,7 +58,6 @@ import com.openexchange.config.Reloadable;
 import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.AbstractOAuthServiceMetaData;
-import com.openexchange.session.Session;
 
 /**
  * {@link OAuthServiceMetaDataYahooImpl}
@@ -86,11 +85,13 @@ public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData
     }
 
     @Override
-    public String modifyCallbackURL(String callbackUrl, String currentHost, Session session) {
-        if (deferrer == null) {
-            return callbackUrl;
-        }
-        return deferrer.getDeferredURL(callbackUrl, session.getUserId(), session.getContextId());
+    public boolean registerTokenBasedDeferrer() {
+        return true;
+    }
+
+    @Override
+    public boolean needsRequestToken() {
+        return true;
     }
 
     @Override
