@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.xing.exception;
 
 import java.io.BufferedReader;
 import java.io.IOException;
+import com.openexchange.java.Streams;
 
 /**
  * Indicates there was trouble parsing a response from Xing.
@@ -68,23 +69,23 @@ public class XingParseException extends XingException {
     }
 
     public static String stringifyBody(BufferedReader reader) {
-        String inputLine = null;
+        if (null == reader) {
+            return "";
+        }
 
         try {
-            if (reader != null) {
-                reader.reset();
-            }
+            reader.reset();
         } catch (IOException ioe) {
-        }
-        StringBuffer result = new StringBuffer();
-        try {
-            while ((inputLine = reader.readLine()) != null) {
-                result.append(inputLine);
-            }
-        } catch (IOException e) {
+            // Ignore
         }
 
-        return result.toString();
+        try {
+            String str = Streams.reader2string(reader);
+            return null == str ? "" : str;
+        } catch (IOException e) {
+            // Ignore
+        }
+        return "";
     }
 
     public XingParseException(String message) {
